@@ -653,60 +653,8 @@ class LaharFlowData(object):
             raise RuntimeWarning('Unable to get data from {}'.format(filename))
     
     def _get_data_nc(self, LaharFlowFile):
-        rgrp = nc.Dataset(LaharFlowFile, 'r')
 
-        tiles = list(rgrp.groups)
-        nc_variables = list(rgrp[tiles[0]].variables)
-
-        nX = self.nXpertile
-        nY = self.nYpertile
-        nXY = nX*nY
-        nrows = len(tiles)*nXY
-
-        variables = nc_variables.copy()
-
-        dt = [('tile',int)]
-        for v in variables:
-            if v=='x':
-                vname = 'x_distance'
-            elif v=='y':
-                vname = 'y_distance'
-            else:
-                vname = v
-            dt.append((vname, rgrp[tiles[0]][v].dtype))
-
-        data = np.empty((nrows,), dtype=dt)
-        
-        #data[:] = np.nan
-
-        if 'x' in variables:
-            variables.remove('x')
-        if 'y' in variables:
-            variables.remove('y')
-
-        if 'x_distance' in variables:
-            variables.remove('x_distance')
-        if 'y_distance' in variables:
-            variables.remove('y_distance')
-
-        for i, t in enumerate(tiles):
-            grp = rgrp[t]
-            if 'x' in nc_variables:
-                x = grp['x'][:]
-            elif 'x_distance' in nc_variables:
-                x = grp['x_distance'][:]
-            if 'y' in nc_variables:
-                y = grp['y'][:]
-            elif 'y_distance' in nc_variables:
-                y = grp['y_distance'][:]
-            Y, X = np.meshgrid(y,x)
-            data['tile'][i*nXY:(i+1)*nXY] = int(t)
-            data['x_distance'][i*nXY:(i+1)*nXY] = X.flatten()
-            data['y_distance'][i*nXY:(i+1)*nXY] = Y.flatten()
-            for v in variables:
-                data[v][i*nXY:(i+1)*nXY] = grp[v][:].flatten()
-        
-        rgrp.close()
+        data = nc2np(LaharFlowFile)
 
         data = np_rename_fields(data, {'lat':'latitude', 'lon':'longitude'})
 
@@ -1458,6 +1406,7 @@ class LaharFlowData(object):
                  vmin=0.1,
                  vmax=None,
                  vcut=None,
+                 clip_low = False,
                  interpolation='nearest',
                  cmap=plt.cm.viridis,
                  cax=None,
@@ -1472,19 +1421,29 @@ class LaharFlowData(object):
 
         fmt = _get_LF_output_fmt(variable, filetype=filetype)
 
-        raster = self.raster(result, crs=crs, nodata=np.nan)
+        raster = self.raster(result, var=[variable], crs=crs, nodata=np.nan)
 
-        dataArray = raster[variable]
+        data = raster[variable].data
+        x = raster[variable].x
+        y = raster[variable].y
 
         if vmax is None:
-            maxval = np.nanmax(dataArray.data)
+            maxval = np.nanmax(data)
             vmax = _nice_round(maxval)
         
-        if vmin is not None:
-            data = np.ma.masked_less(dataArray.data, vmin)
+        if vmin is None:
+            vmin = np.nanmin(data)
         
         if vcut is not None:
             data = np.ma.masked_inside(data, vcut[0], vcut[1])
+        
+        if vmin<0 and vmax>0:
+            cnorm = colors.TwoSlopeNorm(vmin=vmin, vmax=vmax, vcenter=0)
+        else:
+            cnorm = colors.Normalize(vmin=vmin, vmax=vmax)
+        
+        if clip_low:
+            data = np.ma.masked_below(data, vmin)
 
         if ax is None:
             fig, ax = plt.subplots()
@@ -1492,12 +1451,11 @@ class LaharFlowData(object):
         im = ax.imshow(data,
                        interpolation=interpolation,
                        cmap=cmap,
-                       extent=[min(dataArray.x), max(dataArray.x), min(dataArray.y), max(dataArray.y)],
+                       extent=[min(x), max(x), min(y), max(y)],
                        zorder=1,
-                       vmin=vmin,
-                       vmax=vmax)
+                       norm=cnorm)
 
-        if cax is not None:
+        if cax is None:
             divider = make_axes_locatable(ax)
             cax = divider.append_axes("right", size="5%", pad=0.05)
         
